@@ -49,12 +49,13 @@ namespace Banshee.Sources
         public int Position;
     }
     
-    public class SourceManager : ISourceManager, IDisposable
+    public class SourceManager : ISourceManager, IRequiredService, IDisposable
     {
         private List<Source> sources = new List<Source>();
         private Source active_source;
         private Source default_source;
-        private LibrarySource library_source;
+        private MusicLibrarySource music_library;
+        private VideoLibrarySource video_library;
         
         public event SourceEventHandler SourceUpdated;
         public event SourceAddedHandler SourceAdded;
@@ -107,8 +108,10 @@ namespace Banshee.Sources
                 handler(args);
             }
 
-            if (source is LibrarySource) {
-                library_source = source as LibrarySource;
+            if (source is MusicLibrarySource) {
+                music_library = source as MusicLibrarySource;
+            } else if (source is VideoLibrarySource) {
+                video_library = source as VideoLibrarySource;
             }
             
             ServiceManager.DBusServiceManager.RegisterObject(source);
@@ -218,8 +221,12 @@ namespace Banshee.Sources
             set { default_source = value; }
         }
 
-        public LibrarySource Library {
-            get { return library_source; }
+        public MusicLibrarySource MusicLibrary {
+            get { return music_library; }
+        }
+
+        public VideoLibrarySource VideoLibrary {
+            get { return video_library; }
         }
 
         public Source ActiveSource {
@@ -242,6 +249,10 @@ namespace Banshee.Sources
         
         public void SetActiveSource(Source source, bool notify)
         {
+            if(source == null || active_source == source) {
+                return;
+            }
+            
             if(active_source != null) {
                 active_source.Deactivate();
             }
